@@ -16,7 +16,7 @@ class Animado(Actor):
     Una de las variantes que introduce este actor es el
     método 'definir_cuadro', que facilita la animación de personajes.
 
-    Por ejemplo, si tenemos una grilla con un pongüino, podríamos
+    Por ejemplo, si tenemos una grilla con un pingüino, podríamos
     mostrarlo usando este código:
 
         >>> grilla = pilas.imagenes.cargar_grilla("pingu.png", 10)
@@ -29,12 +29,25 @@ class Animado(Actor):
     """
 
     def __init__(self, grilla, x=0, y=0):
+        """ Constructor del Actor.
+
+        :param grilla: Grilla de imagenes obtenida mediante pilas.imagenes.cargar_grilla()
+        :type grilla: `Grilla`
+        :param x: Posición horizontal del Actor.
+        :type x: int
+        :param y: Posición vertical del Actor.
+        :type y: int
+        """
         Actor.__init__(self, x=x, y=y)
         self.imagen = copy.copy(grilla)
         self.definir_cuadro(0)
 
     def definir_cuadro(self, indice):
-        "Permite cambiar el cuadro de animación a mostrar"
+        """ Permite cambiar el cuadro de animación a mostrar
+
+        :param indice: Número del frame de la grilla que se quiere monstrar.
+        :type indice: int
+        """
         self.imagen.definir_cuadro(indice)
         # FIX: Esta sentencia es muy ambigua, porque no todos actores se deben centrar en ese punto.
         self.centro = ('centro', 'centro')
