@@ -9,6 +9,7 @@
 import pilas
 from pilas.actores import Actor
 
+
 class Banana(Actor):
     """Muestra una banana que se combina (temáticamente) con el actor Mono.
 
@@ -25,15 +26,22 @@ class Banana(Actor):
         >>> banana.abrir()
         >>> banana.cerrar()
 
-    
     """
 
     def __init__(self, x=0, y=0):
+        """ Constructor de la Banana.
+
+        :param x: Posición horizontal del Actor.
+        :type x: int
+        :param y: Posición vertical del Actor.
+        :type y: int
+        """
         Actor.__init__(self, x=x, y=y)
         self.imagen = pilas.imagenes.cargar_grilla("banana.png", 2)
         self.definir_cuadro(0)
 
     def definir_cuadro(self, indice):
+        """ Define el frame de la Banana a mostrar."""
         self.imagen.definir_cuadro(indice)
 
     def abrir(self):
@@ -41,5 +49,5 @@ class Banana(Actor):
         self.definir_cuadro(1)
 
     def cerrar(self):
-        """Muestra el gráfico de banana normal (con cáscara)"""
+        """Muestra el gráfico de banana normal (con cáscara)."""
         self.definir_cuadro(0)
