@@ -8,8 +8,8 @@
 
 from PyQt4 import QtCore, QtGui
 from PyQt4.QtCore import Qt
-#from PyQt4.QtOpenGL import QGLWidget
-from PyQt4.QtGui import QWidget as QGLWidget
+from PyQt4.QtOpenGL import QGLWidget
+from PyQt4.QtGui import QWidget
 from pilas import actores, colores, depurador, eventos, fps
 from pilas import imagenes, simbolos, utils
 import copy
@@ -33,7 +33,7 @@ class Ventana(QtGui.QMainWindow):
         self.canvas.resize_to(self.width(), self.height())
 
 
-class CanvasWidget(QGLWidget):
+class CanvasWidgetAbstracto(object):
 
     def __init__(self, motor, lista_actores, ancho, alto, gestor_escenas, permitir_depuracion, rendimiento):
         QGLWidget.__init__(self, None)
@@ -141,8 +141,6 @@ class CanvasWidget(QGLWidget):
         escala = self.escala
         x, y = utils.convertir_de_posicion_fisica_relativa(e.pos().x()/escala, e.pos().y()/escala)
 
-        dx, dy = x - self.mouse_x, y - self.mouse_y
-
         izquierda, derecha, arriba, abajo = utils.obtener_bordes()
 
         #x = max(min(derecha, x), izquierda)
@@ -151,6 +149,8 @@ class CanvasWidget(QGLWidget):
         x += pilas.mundo.motor.camara_x
         y += pilas.mundo.motor.camara_y
 
+        dx, dy = x - self.mouse_x, y - self.mouse_y
+
         self.gestor_escenas.escena_actual().mueve_mouse.emitir(x=x, y=y, dx=dx, dy=dy)
 
         self.mouse_x = x
@@ -285,14 +285,6 @@ class CanvasWidget(QGLWidget):
         else:
             self.pantalla_completa()
 
-class CanvasWidgetSugar(CanvasWidget):
-
-    def _iniciar_aplicacion(self):
-        self.app = None
-
-    def ejecutar_bucle_principal(self, mundo, ignorar_errores):
-        pass
-
 class BaseActor(object):
 
     def __init__(self):
@@ -411,6 +403,11 @@ class Imagen(object):
         nombre_imagen = os.path.basename(self.ruta_original)
         return "<Imagen del archivo '%s'>" %(nombre_imagen)
 
+class CanvasOpenGlWidget(CanvasWidgetAbstracto, QGLWidget):
+    pass
+
+class CanvasNormalWidget(CanvasWidgetAbstracto, QWidget):
+    pass
 
 class Grilla(Imagen):
 
@@ -468,13 +465,19 @@ class Grilla(Imagen):
 
 
 class Texto(Imagen):
+    CACHE_FUENTES = {}
 
-    def __init__(self, texto, magnitud, motor, vertical=False):
+    def __init__(self, texto, magnitud, motor, vertical=False, fuente=None):
         self.vertical = vertical
-        self._ancho, self._alto = motor.obtener_area_de_texto(texto, magnitud, vertical)
+        self.fuente = fuente
+        self._ancho, self._alto = motor.obtener_area_de_texto(texto, magnitud, vertical, fuente)
 
     def _dibujar_pixmap(self, painter, dx, dy):
-        nombre_de_fuente = painter.font().family()
+        if self.fuente:
+            nombre_de_fuente = Texto.cargar_fuente_desde_cache(self.fuente)
+        else:
+            nombre_de_fuente = painter.font().family()
+
         fuente = QtGui.QFont(nombre_de_fuente, self.magnitud)
         metrica = QtGui.QFontMetrics(fuente)
 
@@ -491,6 +494,30 @@ class Texto(Imagen):
             painter.drawText(dx, dy + self._alto, line)
             dy += metrica.height()
 
+    @classmethod
+    def cargar_fuente_desde_cache(kclass, fuente_como_ruta):
+        """Carga o convierte una fuente para ser utilizada dentro del motor.
+
+        Permite a los usuarios referirse a las fuentes como ruta a archivos, sin
+        tener que preocuparse por el font-family.
+
+        :param fuente_como_ruta: Ruta al archivo TTF que se quiere utilizar.
+
+        Ejemplo:
+
+            >>> Texto.cargar_fuente_desde_cache('myttffile.ttf')
+            'Visitor TTF1'
+        """
+
+        if not fuente_como_ruta in Texto.CACHE_FUENTES.keys():
+            ruta_a_la_fuente = pilas.utils.obtener_ruta_al_recurso(fuente_como_ruta)
+            fuente_id = QtGui.QFontDatabase.addApplicationFont(ruta_a_la_fuente)
+            Texto.CACHE_FUENTES[fuente_como_ruta] = fuente_id
+        else:
+            fuente_id = Texto.CACHE_FUENTES[fuente_como_ruta]
+
+        return str(QtGui.QFontDatabase.applicationFontFamilies(fuente_id)[0])
+
     def ancho(self):
         return self._ancho
 
@@ -695,11 +722,14 @@ class Actor(BaseActor):
             escala_x *= -1
 
         if not self.fijo:
-            x = self.x - pilas.mundo.motor.camara_x
-            y = self.y - pilas.mundo.motor.camara_y
+            dx = pilas.mundo.motor.camara_x
+            dy = pilas.mundo.motor.camara_y
         else:
-            x = self.x
-            y = self.y
+            dx = 0
+            dy = 0
+
+        x = self.x - dx
+        y = self.y - dy
 
         self.imagen.dibujar(painter, x, y, self.centro_x, self.centro_y,
                 escala_x, escala_y, self._rotacion, self._transparencia)
@@ -713,12 +743,18 @@ class SonidoDeshabilitado:
     def __init__(self, player, ruta):
         pass
 
-    def reproducir(self):
+    def reproducir(self, repetir=False):
         pass
 
     def detener(self):
         pass
 
+    def pausar(self):
+        pass
+
+    def continuar(self):
+        pass
+
 class MusicaDeshabilitada(SonidoDeshabilitado):
 
     def __init__(self, media, ruta):
@@ -732,16 +768,32 @@ class SonidoGST:
     def __init__(self, player, ruta):
         self.ruta = ruta
         self.sonido = player
-        self.sonido.set_property('uri','file://'+ruta)
+        self.sonido.set_property('uri', 'file://{}'.format(self.ruta))
+        self._repetir = None
 
-    def reproducir(self):
+    def _play(self):
         import gst
+        self.sonido.set_state(gst.STATE_NULL)
+        self.sonido.set_state(gst.STATE_PLAYING)
+
+    def reproducir(self, repetir=False):
+        import gst
+        import pilas
         if not self.deshabilitado:
-            self.sonido.set_state(gst.STATE_NULL)
-            self.sonido.set_state(gst.STATE_PLAYING)
+            self.detener()
+            self._play()
+            if repetir:
+                self.sonido.get_state()
+                nanosecs = float(self.sonido.query_duration(gst.FORMAT_TIME)[0])
+                duracion =  (nanosecs + 10) / gst.SECOND
+                self._repetir = pilas.mundo.agregar_tarea_siempre(duracion,
+                                                                  self._play)
 
     def detener(self):
         import gst
+        if self._repetir:
+            self._repetir.terminar()
+            self._repetir = None
         self.sonido.set_state(gst.STATE_NULL)
 
 
@@ -763,14 +815,40 @@ class SonidoPhonon:
         self.source = phonon.Phonon.MediaSource(ruta)
         self.sonido = phonon.Phonon.createPlayer(phonon.Phonon.GameCategory, self.source)
 
-    def reproducir(self):
+    def _play(self):
         if not self.deshabilitado:
             self.sonido.seek(0)
             self.sonido.play()
 
+    def reproducir(self, repetir=False):
+        if not self.deshabilitado:
+            if repetir:
+                try:
+                    self.sonido.finished.disconnect(self._play)
+                except TypeError:
+                    pass
+                self.sonido.finished.connect(self._play)
+            else:
+                try:
+                    self.sonido.finished.disconnect(self._play)
+                except TypeError:
+                    pass
+            self._play()
+
     def detener(self):
+        "Detiene el audio."
         self.sonido.stop()
 
+    def pausar(self):
+        "Hace una pausa del audio."
+        self.sonido.pause()
+
+    def continuar(self):
+        "Continúa reproduciendo el audio."
+        if not self.deshabilitado:
+            self.sonido.play()
+
+
 class MusicaPhonon(SonidoPhonon):
 
     def __init__(self, media, ruta):
@@ -789,8 +867,7 @@ class Motor(object):
     """
 
     def __init__(self, usar_motor, permitir_depuracion, audio):
-        if usar_motor not in ['qtwidget', 'qtsugar']:
-            self._iniciar_aplicacion()
+        self._iniciar_aplicacion()
 
         self.usar_motor = usar_motor
 
@@ -837,23 +914,27 @@ class Motor(object):
             self.clase_musica = MusicaPhonon
         elif audio == 'gst':
             import gst
-            self.player = gst.element_factory_make("playbin", "player")
+            self.player = gst.element_factory_make("playbin2", "player")
             self.clase_sonido = SonidoGST
             self.clase_musica = MusicaGST
 
     def terminar(self):
         self.ventana.close()
 
-    def iniciar_ventana(self, ancho, alto, titulo, pantalla_completa, gestor_escenas, rendimiento):
+    def iniciar_ventana(self, ancho, alto, titulo, pantalla_completa, gestor_escenas, rendimiento, centrado):
         self.ventana = Ventana()
         self.ventana.resize(ancho, alto)
 
-        if self.usar_motor in ['qtwidget', 'qtsugar']:
-            mostrar_ventana = False
-            self.canvas = CanvasWidgetSugar(self, actores.todos, ancho, alto, gestor_escenas, self.permitir_depuracion, rendimiento)
+        if centrado:
+            resolucion_pantalla = QtGui.QDesktopWidget().screenGeometry()
+            self.ventana.move((resolucion_pantalla.width() - ancho)/2, (resolucion_pantalla.height() - alto)/2)
+
+        mostrar_ventana = True
+
+        if self.usar_motor == 'qtgl':
+            self.canvas = CanvasOpenGlWidget(self, actores.todos, ancho, alto, gestor_escenas, self.permitir_depuracion, rendimiento)
         else:
-            mostrar_ventana = True
-            self.canvas = CanvasWidget(self, actores.todos, ancho, alto, gestor_escenas, self.permitir_depuracion, rendimiento)
+            self.canvas = CanvasNormalWidget(self, actores.todos, ancho, alto, gestor_escenas, self.permitir_depuracion, rendimiento)
 
         self.ventana.set_canvas(self.canvas)
         self.canvas.setFocus()
@@ -906,12 +987,16 @@ class Motor(object):
     def obtener_area(self):
         return (self.ancho_original, self.alto_original)
 
-    def obtener_area_de_texto(self, texto, magnitud=10, vertical=False):
+    def obtener_area_de_texto(self, texto, magnitud=10, vertical=False, fuente=None):
         ancho = 0
         alto = 0
 
-        fuente = QtGui.QFont()
-        fuente.setPointSize(magnitud)
+        if fuente:
+            nombre_de_fuente = Texto.cargar_fuente_desde_cache(fuente)
+        else:
+            nombre_de_fuente = ''
+
+        fuente = QtGui.QFont(nombre_de_fuente, magnitud)
         metrica = QtGui.QFontMetrics(fuente)
 
         if vertical:
@@ -928,8 +1013,8 @@ class Motor(object):
     def obtener_actor(self, imagen, x, y):
         return Actor(imagen, x, y)
 
-    def obtener_texto(self, texto, magnitud, vertical=False):
-        return Texto(texto, magnitud, self, vertical)
+    def obtener_texto(self, texto, magnitud, vertical=False, fuente=None):
+        return Texto(texto, magnitud, self, vertical, fuente)
 
     def obtener_grilla(self, ruta, columnas, filas):
         return Grilla(ruta, columnas, filas)
@@ -938,7 +1023,7 @@ class Motor(object):
         return self.clase_sonido(self.player, ruta)
 
     def cargar_musica(self, ruta):
-        return Musica(self.player, ruta)
+        return self.clase_musica(self.player, ruta)
 
     def deshabilitar_sonido(self, estado=True):
         self.clase_sonido.deshabilitado = estado
